@@ -8,6 +8,11 @@
  *
  */
 #include <gnuradio/pmt_fmt.h>
+
+/* ensure that tweakme.h is included before the bundled spdlog/fmt header, see
+ * https://github.com/gabime/spdlog/issues/2922 */
+#include <spdlog/tweakme.h>
+
 #include <pmt/pmt.h>
 #include <spdlog/fmt/fmt.h>
 #include <string_view>
