@@ -22,7 +22,6 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
-#include <boost/format.hpp>
 #include <cstdio>
 #include <stdexcept>
 
@@ -52,9 +51,7 @@ oss_sink::oss_sink(int sampling_rate, const std::string device_name, bool ok_to_
       d_chunk_size(0)
 {
     if ((d_fd = open(d_device_name.c_str(), O_WRONLY)) < 0) {
-        GR_LOG_ERROR(d_logger,
-                     boost::format("opening device %s: %s") % d_device_name %
-                         strerror(errno));
+        d_logger->error("opening device {:s}: {:s}", d_device_name, strerror(errno));
         throw std::runtime_error("audio_oss_sink");
     }
 
@@ -69,36 +66,32 @@ oss_sink::oss_sink(int sampling_rate, const std::string device_name, bool ok_to_
     int format = AFMT_S16_NE;
     int orig_format = format;
     if (ioctl(d_fd, SNDCTL_DSP_SETFMT, &format) < 0) {
-        GR_LOG_ERROR(d_logger,
-                     boost::format("%s ioctl failed: %s") % d_device_name %
-                         strerror(errno));
+        d_logger->error("{:s} ioctl failed: {:s}", d_device_name, strerror(errno));
         throw std::runtime_error("audio_oss_sink");
     }
 
     if (format != orig_format) {
-        GR_LOG_ERROR(
-            d_logger,
-            boost::format("%s unable to support format %d. card requested %d instead.") %
-                orig_format % format);
+        d_logger->error(
+            "{:s} unable to support format {:d}. card requested {:d} instead.",
+            d_device_name,
+            orig_format,
+            format);
     }
 
     // set to stereo no matter what.  Some hardware only does stereo
     int channels = 2;
     if (ioctl(d_fd, SNDCTL_DSP_CHANNELS, &channels) < 0 || channels != 2) {
-        GR_LOG_ERROR(d_logger,
-                     boost::format("could not set STEREO mode: %s") % strerror(errno));
+        d_logger->error("could not set STEREO mode: {:s}", strerror(errno));
         throw std::runtime_error("audio_oss_sink");
     }
 
     // set sampling freq
     int sf = sampling_rate;
     if (ioctl(d_fd, SNDCTL_DSP_SPEED, &sf) < 0) {
-        GR_LOG_ERROR(d_logger,
-                     boost::format("%s: invalid sampling_rate %d") % d_device_name %
-                         sampling_rate);
+        d_logger->error("{:s}: invalid sampling_rate {:d}", d_device_name, sampling_rate);
         sampling_rate = 8000;
         if (ioctl(d_fd, SNDCTL_DSP_SPEED, &sf) < 0) {
-            GR_LOG_ERROR(d_logger, "failed to set sampling_rate to 8000");
+            d_logger->error("failed to set sampling_rate to 8000");
             throw std::runtime_error("audio_oss_sink");
         }
     }
@@ -127,7 +120,7 @@ int oss_sink::work(int noutput_items,
             }
             f0 += d_chunk_size;
             if (write(d_fd, d_buffer, 2 * d_chunk_size * sizeof(short)) < 0)
-                GR_LOG_ERROR(d_logger, boost::format("write %s") % strerror(errno));
+                d_logger->error("write {:s}", strerror(errno));
         }
         break;
 
@@ -143,7 +136,7 @@ int oss_sink::work(int noutput_items,
             f0 += d_chunk_size;
             f1 += d_chunk_size;
             if (write(d_fd, d_buffer, 2 * d_chunk_size * sizeof(short)) < 0)
-                GR_LOG_ERROR(d_logger, boost::format("write %s") % strerror(errno));
+                d_logger->error("write {:s}", strerror(errno));
         }
         break;
     }
