@@ -11,14 +11,14 @@
 #ifndef INCLUDED_AUDIO_PORTAUDIO_IMPL_H
 #define INCLUDED_AUDIO_PORTAUDIO_IMPL_H
 
+#include <gnuradio/logger.h>
 #include <portaudio.h>
-#include <cstdio>
 
 namespace gr {
 namespace audio {
 
 PaDeviceIndex pa_find_device_by_name(const char* name);
-void print_devices();
+void print_devices(const gr::logger_ptr& logger);
 
 } /* namespace audio */
 } /* namespace gr */
