@@ -23,14 +23,17 @@ private:
     constellation_sptr d_constellation;
     unsigned int d_dim;
     unsigned int d_bps;
+    float d_npwr;
     gr::thread::mutex d_mutex;
     bool d_warned_bps = false; // To record if a bps change warning has been raised, and
                                // limit logging spam
 
 public:
-    constellation_soft_decoder_cf_impl(constellation_sptr constellation);
+    constellation_soft_decoder_cf_impl(constellation_sptr constellation,
+                                       float npwr = 1.0);
     ~constellation_soft_decoder_cf_impl() override;
 
+    void set_npwr(float npwr) override;
     void set_constellation(constellation_sptr constellation) override;
 
     int work(int noutput_items,
