@@ -18,6 +18,8 @@
 namespace gr {
 namespace fec {
 
+static const pmt::pmt_t ITERATIONS_KEY = pmt::mp("iterations");
+
 class FEC_API async_decoder_impl : public async_decoder
 {
 private:
@@ -34,11 +36,16 @@ private:
 
     size_t d_max_bits_in;
     volk::vector<float> d_tmp_f32;
-    volk::vector<int8_t> d_tmp_u8;
+    volk::vector<uint8_t> d_tmp_u8;
     volk::vector<uint8_t> d_bits_out;
 
-    void decode_packed(pmt::pmt_t msg);
-    void decode_unpacked(pmt::pmt_t msg);
+    void decode(const pmt::pmt_t& msg);
+
+    inline void convert_32f_to_8u(uint8_t* output_vector,
+                                  const float* input_vector,
+                                  const float scale,
+                                  const float bias,
+                                  unsigned int num_points);
 
 public:
     async_decoder_impl(generic_decoder::sptr my_decoder,
