@@ -17,8 +17,6 @@
 #include <gnuradio/logger.h>
 #include <volk/volk.h>
 
-#include <boost/format.hpp>
-
 namespace gr {
 namespace fec {
 
@@ -96,10 +94,10 @@ void async_encoder_impl::encode_unpacked(pmt::pmt_t msg)
     } else {
         nblocks = nbits_in / d_encoder->get_input_size();
         if (nblocks * d_encoder->get_input_size() != nbits_in) {
-            GR_LOG_ERROR(
-                d_logger,
-                boost::format("nblocks: %u, in_block_size: %d, got_input_size: %d") %
-                    nblocks % d_encoder->get_input_size() % nbits_in);
+            d_logger->error("nblocks: {:d}, in_block_size: {:d}, got_input_size: {:d}",
+                            nblocks,
+                            d_encoder->get_input_size(),
+                            nbits_in);
             throw std::runtime_error("input does not divide into code block size!");
         }
         nbits_out = nblocks * d_encoder->get_output_size();
