@@ -44,7 +44,7 @@ pfb_arb_resampler_ccf::pfb_arb_resampler_ccf(float rate,
     d_last_filter = (taps.size() / 2) % filter_size;
 
     // Create an FIR filter for each channel and zero out the taps
-    const std::vector<float> vtaps(0, d_int_rate);
+    const std::vector<float> vtaps(d_int_rate, 0.0);
     d_filters.reserve(d_int_rate);
     d_diff_filters.reserve(d_int_rate);
     for (unsigned int i = 0; i < d_int_rate; i++) {
@@ -236,7 +236,7 @@ pfb_arb_resampler_ccc::pfb_arb_resampler_ccc(float rate,
     d_diff_filters.reserve(d_int_rate);
 
     // Create an FIR filter for each channel and zero out the taps
-    const std::vector<gr_complex> vtaps(0, d_int_rate);
+    const std::vector<gr_complex> vtaps(d_int_rate, 0.0);
     for (unsigned int i = 0; i < d_int_rate; i++) {
         d_filters.emplace_back(vtaps);
         d_diff_filters.emplace_back(vtaps);
@@ -429,7 +429,7 @@ pfb_arb_resampler_fff::pfb_arb_resampler_fff(float rate,
     d_diff_filters.reserve(d_int_rate);
 
     // Create an FIR filter for each channel and zero out the taps
-    const std::vector<float> vtaps(0, d_int_rate);
+    const std::vector<float> vtaps(d_int_rate, 0.0);
     for (unsigned int i = 0; i < d_int_rate; i++) {
         d_filters.emplace_back(vtaps);
         d_diff_filters.emplace_back(vtaps);
