@@ -28,14 +28,21 @@ private:
     std::string d_name;
     int d_nconnections;
 
-    int d_index, d_start, d_end;
-    std::vector<double*> d_residbufs_real;
-    std::vector<double*> d_residbufs_imag;
+    int d_index = 0;
+    int d_start;
+    int d_end;
+    std::vector<volk::vector<double>> d_residbufs_real;
+    std::vector<volk::vector<double>> d_residbufs_imag;
 
-    int d_argc;
-    char* d_argv;
+    // Required now for Qt; argc must be greater than 0 and argv
+    // must have at least one valid character. Must be valid through
+    // life of the qApplication:
+    // http://harmattan-dev.nokia.com/docs/library/html/qt4/qapplication.html
+    char d_zero = 0;
+    int d_argc = 1;
+    char* d_argv = &d_zero;
     QWidget* d_parent;
-    ConstellationDisplayForm* d_main_gui;
+    ConstellationDisplayForm* d_main_gui = nullptr;
 
     gr::high_res_timer_type d_update_time;
     gr::high_res_timer_type d_last_time;
@@ -66,6 +73,12 @@ public:
                       QWidget* parent = NULL);
     ~const_sink_c_impl() override;
 
+    // Disallow copy/move because of the pointers.
+    const_sink_c_impl(const const_sink_c_impl&) = delete;
+    const_sink_c_impl& operator=(const const_sink_c_impl&) = delete;
+    const_sink_c_impl(const_sink_c_impl&&) = delete;
+    const_sink_c_impl& operator=(const_sink_c_impl&&) = delete;
+
     bool check_topology(int ninputs, int noutputs) override;
 
     void exec_() override;
