@@ -17,10 +17,6 @@
 #include <qpainter.h>
 #include <qpen.h>
 
-#if QWT_VERSION < 0x060000
-#include "qwt_double_interval.h"
-#endif
-
 typedef QVector<QRgb> QwtColorTable;
 
 class PlotWaterfallImage : public QImage
@@ -100,9 +96,6 @@ int PlotWaterfall::rtti() const { return QwtPlotItem::Rtti_PlotSpectrogram; }
 void PlotWaterfall::setColorMap(const QwtColorMap& colorMap)
 {
     delete d_data->colorMap;
-#if QWT_VERSION < 0x060000
-    d_data->colorMap = colorMap.copy();
-#endif
 
     invalidateCache();
     itemChanged();
@@ -114,30 +107,6 @@ void PlotWaterfall::setColorMap(const QwtColorMap& colorMap)
 */
 const QwtColorMap& PlotWaterfall::colorMap() const { return *d_data->colorMap; }
 
-/*!
-  \return Bounding rect of the data
-  \sa QwtRasterData::boundingRect
-*/
-#if QWT_VERSION < 0x060000
-QwtDoubleRect PlotWaterfall::boundingRect() const { return d_data->data->boundingRect(); }
-#endif
-
-/*!
-  \brief Returns the recommended raster for a given rect.
-
-  F.e the raster hint is used to limit the resolution of
-  the image that is rendered.
-
-  \param rect Rect for the raster hint
-  \return data().rasterHint(rect)
-*/
-#if QWT_VERSION < 0x060000
-QSize PlotWaterfall::rasterHint(const QwtDoubleRect& rect) const
-{
-    return d_data->data->rasterHint(rect);
-}
-#endif
-
 /*!
   \brief Render an image from the data and color map.
 
@@ -155,27 +124,16 @@ QSize PlotWaterfall::rasterHint(const QwtDoubleRect& rect) const
   \sa QwtRasterData::intensity(), QwtColorMap::rgb(),
   QwtColorMap::colorIndex()
 */
-#if QWT_VERSION < 0x060000
-QImage PlotWaterfall::renderImage(const QwtScaleMap& xMap,
-                                  const QwtScaleMap& yMap,
-                                  const QwtDoubleRect& area) const
-#else
 QImage PlotWaterfall::renderImage(const QwtScaleMap& xMap,
                                   const QwtScaleMap& yMap,
                                   const QRectF& area,
                                   const QSize& size) const
-#endif
 {
     if (area.isEmpty())
         return QImage();
 
-#if QWT_VERSION < 0x060000
-    QRect rect = transform(xMap, yMap, area);
-    const QSize res = d_data->data->rasterHint(area);
-#else
     QRect rect(0, 0, 0, 0);
     const QSize res(0, 0);
-#endif
 
     QwtScaleMap xxMap = xMap;
     QwtScaleMap yyMap = yMap;
@@ -217,11 +175,7 @@ QImage PlotWaterfall::renderImage(const QwtScaleMap& xMap,
 
     PlotWaterfallImage image(rect.size(), d_data->colorMap->format());
 
-#if QWT_VERSION < 0x060000
-    const QwtDoubleInterval intensityRange = d_data->data->range();
-#else
     const QwtInterval intensityRange = d_data->data->interval(Qt::ZAxis);
-#endif
     if (!intensityRange.isValid())
         return std::move(image);
 
