@@ -19,13 +19,13 @@ class rfnoc_ddc_impl : public rfnoc_ddc
 {
 public:
     rfnoc_ddc_impl(::uhd::rfnoc::noc_block_base::sptr block_ref);
-    ~rfnoc_ddc_impl();
+    ~rfnoc_ddc_impl() override;
 
     /*** API *****************************************************************/
     double set_freq(const double freq,
                     const size_t chan,
-                    const ::uhd::time_spec_t time = ::uhd::time_spec_t::ASAP);
-    double set_output_rate(const double rate, const size_t chan);
+                    const ::uhd::time_spec_t time = ::uhd::time_spec_t::ASAP) override;
+    double set_output_rate(const double rate, const size_t chan) override;
 
 private:
     ::uhd::rfnoc::ddc_block_control::sptr d_ddc_ref;
