@@ -19,13 +19,13 @@ class rfnoc_duc_impl : public rfnoc_duc
 {
 public:
     rfnoc_duc_impl(::uhd::rfnoc::noc_block_base::sptr block_ref);
-    ~rfnoc_duc_impl();
+    ~rfnoc_duc_impl() override;
 
     /*** API *****************************************************************/
     double set_freq(const double freq,
                     const size_t chan,
-                    const ::uhd::time_spec_t time = ::uhd::time_spec_t::ASAP);
-    double set_input_rate(const double rate, const size_t chan);
+                    const ::uhd::time_spec_t time = ::uhd::time_spec_t::ASAP) override;
+    double set_input_rate(const double rate, const size_t chan) override;
 
 private:
     ::uhd::rfnoc::duc_block_control::sptr d_duc_ref;
