@@ -18,7 +18,6 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
-#include <boost/format.hpp>
 #include <cstdio>
 #include <cstring>
 #include <stdexcept>
@@ -64,10 +63,8 @@ sink_s_impl::sink_s_impl(
 
     atexit(SDL_Quit); // check if this is the way to do this
     if (SDL_Init(SDL_INIT_VIDEO) < 0) {
-        std::ostringstream msg;
-        msg << "Couldn't initialize SDL:" << SDL_GetError()
-            << "; SDL_Init(SDL_INIT_VIDEO) failed";
-        GR_LOG_ERROR(d_logger, msg.str());
+        d_logger->error("Couldn't initialize SDL: {:s}; SDL_Init(SDL_INIT_VIDEO) failed",
+                        SDL_GetError());
         throw std::runtime_error("video_sdl::sink_s");
     };
 
@@ -80,11 +77,9 @@ sink_s_impl::sink_s_impl(
             SDL_ANYFORMAT); // SDL_DOUBLEBUF |SDL_SWSURFACE| SDL_HWSURFACE||SDL_FULLSCREEN
 
     if (d_screen == NULL) {
-        std::ostringstream msg;
-        msg << "Unable to set SDL video mode: " << SDL_GetError()
-            << "; SDL_SetVideoMode() Failed";
-        GR_LOG_ERROR(d_logger, msg.str());
-        exit(1);
+        d_logger->error("Unable to set SDL video mode: {:s}; SDL_SetVideoMode() Failed",
+                        SDL_GetError());
+        throw std::runtime_error("video_sdl::sink_s");
     }
     if (d_image) {
         SDL_FreeYUVOverlay(d_image);
@@ -93,16 +88,13 @@ sink_s_impl::sink_s_impl(
     /* Initialize and create the YUV Overlay used for video out */
     if (!(d_image =
               SDL_CreateYUVOverlay(d_width, d_height, SDL_IYUV_OVERLAY, d_screen))) {
-        std::ostringstream msg;
-        msg << "Couldn't create a YUV overlay: " << SDL_GetError();
-        GR_LOG_ERROR(d_logger, msg.str());
+        d_logger->error("Couldn't create a YUV overlay: {:s}", SDL_GetError());
         throw std::runtime_error("video_sdl::sink_s");
     }
 
-    GR_LOG_INFO(d_debug_logger,
-                boost::format("SDL screen_mode %d bits-per-pixel") %
-                    d_screen->format->BitsPerPixel);
-    GR_LOG_INFO(d_debug_logger, boost::format("SDL overlay_mode %i") % d_image->format);
+    d_debug_logger->info("SDL screen_mode {:d} bits-per-pixel",
+                         d_screen->format->BitsPerPixel);
+    d_debug_logger->info("SDL overlay_mode {:d}", d_image->format);
 
     d_chunk_size = std::min(1, 16384 / width); // width*16;
     d_chunk_size = d_chunk_size * width;
@@ -117,9 +109,7 @@ sink_s_impl::sink_s_impl(
     // clear the surface to grey
 
     if (SDL_LockYUVOverlay(d_image)) {
-        std::ostringstream msg;
-        msg << "Couldn't lock a YUV overlay:" << SDL_GetError();
-        GR_LOG_ERROR(d_logger, msg.str());
+        d_logger->error("Couldn't lock a YUV overlay: {:s}", SDL_GetError());
         throw std::runtime_error("video_sdl::sink_s");
     }
 
@@ -292,11 +282,10 @@ int sink_s_impl::work(int noutput_items,
         }
         break;
     default: // 0 or more then 3 channels
-        std::ostringstream msg;
-        msg << "Wrong number of channels: 1, 2 or 3 channels are supported. Requested "
-               "number of channels is "
-            << input_items.size();
-        GR_LOG_ERROR(d_logger, msg.str());
+        d_logger->error(
+            "Wrong number of channels: 1, 2 or 3 channels are supported. Requested "
+            "number of channels is {:d}",
+            input_items.size());
         throw std::runtime_error("video_sdl::sink_s");
     }
 
