@@ -7,15 +7,17 @@
 
 from codecs import open
 from collections import namedtuple
+from collections import ChainMap
 import os
 import logging
 from itertools import chain
-import re
+from typing import Type
 
 from . import (
     Messages, Constants,
     blocks, params, ports, errors, utils, schema_checker
 )
+from .blocks import Block
 
 from .Config import Config
 from .cache import Cache
@@ -48,13 +50,11 @@ class Platform(Element):
         self.domains = {}
         self.connection_templates = {}
         self.cpp_connection_templates = {}
+        self.connection_params = {}
 
         self._block_categories = {}
         self._auto_hier_block_generate_chain = set()
 
-        if not yaml.__with_libyaml__:
-            logger.warning("Slow YAML loading (libyaml not available)")
-
     def __str__(self):
         return 'Platform - {}'.format(self.config.name)
 
@@ -283,6 +283,7 @@ class Platform(Element):
                 'connect', '')
             self.cpp_connection_templates[connection_id] = connection.get(
                 'cpp_connect', '')
+            self.connection_params[connection_id] = connection.get('parameters', {})
 
     def load_category_tree_description(self, data, file_path):
         """Parse category tree file and add it to list"""
@@ -344,14 +345,28 @@ class Platform(Element):
             from ..converter.flow_graph import from_xml
             data = from_xml(filename)
 
+        file_format = data.get('metadata', {}).get('file_format')
+        if file_format is None:
+            Messages.send(
+                '>>> WARNING: Flow graph does not contain a file format version!\n')
+        elif file_format == 0:
+            Messages.send(
+                '>>> WARNING: Flow graph format is version 0 (legacy) and will'
+                ' be converted to version 1 or higher upon saving!\n')
+        elif file_format > Constants.FLOW_GRAPH_FILE_FORMAT_VERSION:
+            raise RuntimeError(
+                f"Flow graph {filename} has unknown flow graph version!")
+
         return data
 
     def save_flow_graph(self, filename, flow_graph):
         data = flow_graph.export_data()
 
         try:
-            data['connections'] = [yaml.ListFlowing(
-                i) for i in data['connections']]
+            data['connections'] = [
+                yaml.ListFlowing(conn) if isinstance(conn, (list, tuple)) else conn
+                for conn in data['connections']
+            ]
         except KeyError:
             pass
 
@@ -406,7 +421,7 @@ class Platform(Element):
 
     block_classes_build_in = blocks.build_ins
     # separates build-in from loaded blocks)
-    block_classes = utils.backports.ChainMap({}, block_classes_build_in)
+    block_classes = ChainMap({}, block_classes_build_in)
 
     port_classes = {
         None: ports.Port,  # default
@@ -424,10 +439,10 @@ class Platform(Element):
             fg.import_data(data)
         return fg
 
-    def new_block_class(self, **data):
+    def new_block_class(self, **data) -> Type[Block]:
         return blocks.build(**data)
 
-    def make_block(self, parent, block_id, **kwargs):
+    def make_block(self, parent, block_id, **kwargs) -> Block:
         cls = self.block_classes[block_id]
         return cls(parent, **kwargs)
 
